OiRA

Help

1. Προετοιμασία
2. Συμμετοχή των εργαζομένων
3. Αναγνώριση + Αξιολόγηση
4. Σχέδιο Δράσης
5. Έκθεση
6. Παρούσα Κατάσταση 0%

# Προσαρμόστε στις ανάγκες σας την αξιολόγηση κινδύνων για την επιχείρησή σας

Για να προσαρμόσετε την αξιολόγηση κινδύνου στην επιχείρησή σας, μπορεί να σας ζητηθεί να:

- επιλέξετε ή να παρακάμψετε καταστάσεις σχετικές ή όχι με τη δραστηριότητα της επιχείρησής σας και μαρκάρετε με τικ το πλαίσιο(-α) εάν χρειάζεται
- παραθέσετε σε λίστα πολλαπλές επιχειρηματικές μονάδες, κ.λπ. Αυτοί οι σχετικοί κίνδυνοι θα επαναληφθούν για κάθε όνομα που έχετε εισάγει.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More